@@ -30,6 +30,7 @@
  */
 
 #include <cupsfilters/driver.h>
+#include <cupsfilters/colord.h>
 #include "pcl-common.h"
 #include <signal.h>
 
@@ -349,7 +350,8 @@ StartPage(ppd_file_t         *ppd,	/* I - PPD file */
     fprintf(stderr, "DEBUG: Resolution = %s\n", resolution);
 
     snprintf (tmpstr, sizeof(tmpstr), "cups-%s", getenv("PRINTER"));
-    device_inhibited = colord_get_inhibit_for_device_id (tmpstr);
+    if (strcmp(tmpstr, "cups-(null)") != 0) 
+      device_inhibited = colord_get_inhibit_for_device_id (tmpstr);
 
     /* support the "cm-calibration" option */
     if ((cupsGetOption("cm-calibration", num_options, options)) != NULL) {
